CompensatedLogTable

Trait CompensatedLogTable 

pub trait CompensatedLogTable<T = Self>: FloatConsts {
    const LOG_TABLE: [Compensated<T>; 30];
    const LN_2_EXTENDED: [T; 3];
}
Helper trait to store precomputed compensated logarithm table for small integer bases.

Required Associated Constants

const LOG_TABLE: [Compensated<T>; 30]

The log table entries for bases 3..=32 as (high, low) pairs.

const LN_2_EXTENDED: [T; 3]

Third part of extended precision ln(2), where the first two parts are provided by LN_2.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CompensatedLogTable for f32

Source

impl CompensatedLogTable for f64

Source

impl<R: FloatRegister> CompensatedLogTable for Vector<R>

Implementors

Last built: 2026-09-08 21:35:55 UTC